==> huaweicloudsdkgaussdb-3.1.134-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/check_starrocks_params_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckStarrocksParamsRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'source_configuration_id': 'str'
    }

    attribute_map = {
        'source_configuration_id': 'source_configuration_id'
    }

    def __init__(self, source_configuration_id=None):
        """CheckStarrocksParamsRequestBody

        The model defined in huaweicloud sdk

        :param source_configuration_id: 需要进行比较的源参数模板ID。通过ListStarrocksInstanceInfo接口获得。
        :type source_configuration_id: str
        """
        
        

        self._source_configuration_id = None
        self.discriminator = None

        self.source_configuration_id = source_configuration_id

    @property
    def source_configuration_id(self):
        """Gets the source_configuration_id of this CheckStarrocksParamsRequestBody.

        需要进行比较的源参数模板ID。通过ListStarrocksInstanceInfo接口获得。

        :return: The source_configuration_id of this CheckStarrocksParamsRequestBody.
        :rtype: str
        """
        return self._source_configuration_id

    @source_configuration_id.setter
    def source_configuration_id(self, source_configuration_id):
        """Sets the source_configuration_id of this CheckStarrocksParamsRequestBody.

        需要进行比较的源参数模板ID。通过ListStarrocksInstanceInfo接口获得。

        :param source_configuration_id: The source_configuration_id of this CheckStarrocksParamsRequestBody.
        :type source_configuration_id: str
        """
        self._source_configuration_id = source_configuration_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckStarrocksParamsRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/check_starrocks_params_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckStarrocksParamsRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'source_configuration_id': 'str'
    }

    attribute_map = {
        'source_configuration_id': 'source_configuration_id'
    }

    def __init__(self, source_configuration_id=None):
        r"""CheckStarrocksParamsRequestBody

        The model defined in huaweicloud sdk

        :param source_configuration_id: 需要进行比较的源参数模板ID。通过ListStarrocksInstanceInfo接口获得。
        :type source_configuration_id: str
        """
        
        

        self._source_configuration_id = None
        self.discriminator = None

        self.source_configuration_id = source_configuration_id

    @property
    def source_configuration_id(self):
        r"""Gets the source_configuration_id of this CheckStarrocksParamsRequestBody.

        需要进行比较的源参数模板ID。通过ListStarrocksInstanceInfo接口获得。

        :return: The source_configuration_id of this CheckStarrocksParamsRequestBody.
        :rtype: str
        """
        return self._source_configuration_id

    @source_configuration_id.setter
    def source_configuration_id(self, source_configuration_id):
        r"""Sets the source_configuration_id of this CheckStarrocksParamsRequestBody.

        需要进行比较的源参数模板ID。通过ListStarrocksInstanceInfo接口获得。

        :param source_configuration_id: The source_configuration_id of this CheckStarrocksParamsRequestBody.
        :type source_configuration_id: str
        """
        self._source_configuration_id = source_configuration_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckStarrocksParamsRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
